#
# spec file for package squirrel
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define tardir SQUIRREL3
%define tarver 3_0_7

Name:           squirrel
Summary:        A high level imperative/OO programming language
License:        MIT
Group:          Development/Languages/Other
Version:        3.0.7
Release:        4.3
Url:            http://squirrel-lang.org/
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  libtool
Source:         http://downloads.sourceforge.net/project/squirrel/squirrel3/squirrel%203.0.7%20stable/%{name}_%{tarver}_stable.tar.gz
Patch0:         squirrel-autoconfiscate.patch.bz2
Patch1:         squirrel-aliasing.patch
Patch2:         squirrel-ptr_conversion.patch
Patch3:         squirrel-rename_binary.patch
Patch4:         squirrel-gcc47.patch

%description
Squirrel is a light weight programming language
featuring higher-order functions,classes/inheritance,
delegation,tail recursion,generators,cooperative
threads,exception handling, reference counting and
garbage collection on demand. C-like syntax.

%package        devel
Summary:        Development files for %name
Group:          Development/Languages/C and C++
Requires:       %name = %version

%description devel
This package contains everything to embed the Squirrel engine in
your own application.

%package        devel-static
Summary:        Static squirrel libraries
Group:          Development/Languages/C and C++
Requires:       %name = %version

%description devel-static
This package contains the static versions of the engine and
standard lbrary.

%package        doc
Summary:        Documentation for %{name}
Group:          Development/Languages/Other
Requires:       %name = %version
BuildArch:      noarch

%description doc
Documentation files for squirrel.

%package        examples
Summary:        Example scripts for %{name}
Group:          Development/Languages/Other
Requires:       %name = %version
BuildArch:      noarch

%description examples
Example scripts to show squirrel usage.

%prep
%setup -q -n %{tardir}
dos2unix -q $(find . -type f)
%patch0
%patch1
%patch2 -p1
%patch3
%patch4 -p1
find . -type f -exec chmod -x {} \;
chmod +x configure config.guess config.sub depcomp install-sh ltmain.sh missing
autoreconf -fi

%build
export CXXFLAGS="%{optflags} -std=gnu++0x"
export CFLAGS="%{optflags}"
%configure --enable-static
make %{?_smp_mflags}

%install 
%makeinstall
install -d %{buildroot}/%{_defaultdocdir}/%name
install -m 644 README HISTORY COPYRIGHT %{buildroot}/%{_defaultdocdir}/%name

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%files
%defattr(-,root,root,755)
%dir %{_defaultdocdir}/%{name}
%doc %{_defaultdocdir}/%{name}/README
%doc %{_defaultdocdir}/%{name}/HISTORY
%doc %{_defaultdocdir}/%{name}/COPYRIGHT
%{_bindir}/sqrl
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root,755)
%{_includedir}/*
%{_libdir}/*.so

%files devel-static
%defattr(-,root,root,755)
%{_libdir}/*.a
%{_libdir}/*.la

%files doc
%defattr(-,root,root)
%exclude %{_defaultdocdir}/%{name}/README
%exclude %{_defaultdocdir}/%{name}/HISTORY
%exclude %{_defaultdocdir}/%{name}/COPYRIGHT
%{_defaultdocdir}/%name/*

%files examples
%defattr(644,root,root,755)
%{_datadir}/%{name}

%changelog
* Thu Mar 26 2015 p.drouand@gmail.com
- Update to version 3.0.7
  * newthread and sq_newthread() no longer resets the base lib
    function in the root table
  * exceptions in the _inherited metamethod are propagated
  * 'in' operator performance improvement
  * fixed bug in print()
  * fixed some documentation bug
- Use download Url as source
- Update patches;
  * squirrel-gcc47.patch
  * squirrel-ptr_conversion.patch
* Wed Jul 24 2013 coolo@suse.com
- the dirname macro is something special in rpm 4.11, so rename
  the macro to fix build
* Wed May  2 2012 joop.boonen@opensuse.org
- update to version 3.0.2
  + added sq_gethash API
  + now array.sort() is implemented with heapsort
  + now floats in scientific notation also accept numbers with no '.' (eg. 1e+6 or 1e6)
  + fixed some warning
  + fixed some documentation
  + fixed bug in GC
* Sat Mar 24 2012 dimstar@opensuse.org
- Add squirrel-gcc47.patch: Fix build with gcc 4.7.
* Mon Nov 28 2011 coolo@suse.com
- calling autoreconf after patching all about auto* sounds sane
* Tue Nov 15 2011 pth@suse.de
- Change license to MIT (bnc#730449).
* Tue Nov 15 2011 pth@suse.de
- Add copyright to spec file.
* Mon Nov 14 2011 jengelh@medozas.de
- Remove redundant/unwanted tags/section (cf. specfile guidelines)
* Thu Nov 10 2011 pth@suse.de
- Autoconfiscate the package so that handling of libraries and
  installation gets easier.
- Include cstdint/stdint.h and define squirrel types using the
  * _t macros.
- Rename the sq binary to sqrl to fix conflict with ispell.
- Fix aliasing issues by using unions.
* Thu Aug 25 2011 lars@linux-schulserver.de
- update to 3.0: please refer to
  /usr/share/doc/packages/squirrel/HISTORY for all the changes
- split out doc package with all the reference and standard
  libraries manuals
* Sat Sep 26 2009 lars@linux-schulserver.de
- update to 2.2.3
  + added sq_getfunctioninfo
  + added compile time flag SQUSEDOUBLE to use double precision floats
  + added global slot _floatsize_ int the base lib to recognize single
    precision and double precision builds
  + sq_wakeupvm can now resume the vm with an exception
  + added sqstd_format
  + generators can now be instantiated by calling sq_call() or closure.call()
  + fixed a bug in sqstd_printcallstack(thx takayuki_h)
  + fixed modulo by zero(thx jup)
  + fixed negative enums and constants
  + fixed generator crash bug if invoked as tail call (thx Mr.Accident)
  + fixed some minor bug
* Sat Jul 12 2008 lars@linux-schulserver.de
- update to 2.2.1:
  + fixed a tailcall bug
* Fri Mar 21 2008 lars@linux-schulserver.de
- update to 2.2
* Tue Dec 25 2007 lars@linux-schulserver.de
- initial version 2.1.2
